@@ -12,10 +12,10 @@
 from .commons import (FinishCommand as BaseFinishCommand, GitHubCommand,
         ReviewCommand as BaseReviewCommand, StartCommand as BaseStartCommand,
         TasksCommand as BaseTasksCommand)
-from .utils import cached_property
+from .utils import less
 from clint.textui import colored, puts
-from continuity.github import Issue
-from pydoc import pipepager
+from continuity.services.github import Issue
+from continuity.services.utils import cached_property
 from StringIO import StringIO
 from sys import exit
 
@@ -140,7 +140,7 @@ class IssuesCommand(GitHubCommand):
             message = "{0}: {1}\n".format(number, title.strip())
             output.write(message)
 
-        pipepager(output.getvalue(), cmd="less -FRSX")
+        less(output)
 
 
 class ReviewCommand(BaseReviewCommand):
@@ -215,7 +215,7 @@ class StartCommand(BaseStartCommand, GitHubCommand):
         available = lambda issue: issue and \
             issue.state == Issue.STATE_OPEN and \
             not("started" in issue.labels or "finished" in issue.labels) and \
-            issue.pull_request.url is None
+            issue.pull_request is None
         number = self.namespace.number
         exclusive = self.namespace.exclusive
         user = self.github.get_user()
